@@ -76,16 +76,13 @@ GLOBALS = globals()
 starmods = ('clu.repl.ansi',
             'clu.repl.columnize',
             'clu.repl.modules',
-            'clu.constants.enums',
-            'clu.constants.data',
-            'clu.application',
             'clu.config.abc',
             'clu.config.env',
             'clu.config.keymap',
             'clu.config.proxy',
-            'clu.dicts', 'clu.enums', 'clu.exporting',
+            'clu.dicts', 'clu.exporting',
             'clu.importing', 'clu.naming', 'clu.predicates', 'clu.typology',
-            'clu.fs.abc', 'clu.fs.filesystem', 'clu.fs.misc', 'clu.repr',
+            'clu.fs.filesystem', 'clu.fs.misc',
             'clu.scripts.treeline',
             'clu.typespace.namespace',
             'clu.testing.utils')
@@ -94,15 +91,20 @@ mods = ('clu',
         'clu.all',
         'clu.abstract',
         'clu.constants.consts',
+        'clu.constants.data',
+        'clu.constants.enums',
         'clu.constants.polyfills',
         'clu.config.codecs',
         'clu.config.ns',
         'clu.csv',
+        'clu.enums',
+        'clu.fs.abc',
         'clu.fs.appdirectories',
         'clu.keyvalue',
         'clu.mathematics',
         'clu.dispatch', 'clu.sanitizer', 'clu.fs.pypath',
         'clu.extending', 'clu.shelving.redat',
+        'clu.repr',
         'clu.scripts.ansicolors',
         'clu.scripts.treeline',
         'clu.stdio',
@@ -113,7 +115,7 @@ mods = ('clu',
         'datetime', 'functools', 'importlib', 'inspect',
         'itertools', 'math', 'operator', 'pathlib',
         'pickle', 'six', 'shutil', 'sysconfig', 'weakref',
-        'numpy', 'more_itertools', 'colorama',
+        'numpy', 'colorama',
         'xerox', 'zict')
 
 # “Star-import” all starmods – this is equivalent to doing:
